@@ -16,12 +16,11 @@ import requests
 import uvicorn
 
 from gradio import queueing
-from gradio.routes import app
+from gradio.routes import App
 from gradio.tunneling import create_tunnel
 
 if TYPE_CHECKING:  # Only import for type checking (to avoid circular imports).
-    from gradio.launchable import Launchable
-
+    from gradio.blocks import Blocks
 
 # By default, the local server will try to open on localhost, port 7860.
 # If that is not available, then it will try 7861, 7862, ... 7959.
@@ -65,13 +64,29 @@ def get_first_available_port(initial: int, final: int) -> int:
             pass
     raise OSError(
         "All ports from {} to {} are in use. Please close a port.".format(
-            initial, final
+            initial, final - 1
         )
     )
 
 
+def configure_app(app: fastapi.FastAPI, blocks: Blocks) -> fastapi.FastAPI:
+    auth = blocks.auth
+    if auth is not None:
+        if not callable(auth):
+            app.auth = {account[0]: account[1] for account in auth}
+        else:
+            app.auth = auth
+    else:
+        app.auth = None
+    app.blocks = blocks
+    app.cwd = os.getcwd()
+    app.favicon_path = blocks.favicon_path
+    app.tokens = {}
+    return app
+
+
 def start_server(
-    launchable: Launchable,
+    blocks: Blocks,
     server_name: Optional[str] = None,
     server_port: Optional[int] = None,
     ssl_keyfile: Optional[str] = None,
@@ -80,10 +95,10 @@ def start_server(
 ) -> Tuple[int, str, fastapi.FastAPI, Server]:
     """Launches a local server running the provided Interface
     Parameters:
-    launchable: The launchable object to run on the server
+    blocks: The Blocks object to run on the server
     server_name: to make app accessible on local network, set this to "0.0.0.0". Can be set by environment variable GRADIO_SERVER_NAME.
     server_port: will start gradio app on this port (if available). Can be set by environment variable GRADIO_SERVER_PORT.
-    auth: If provided, username and password (or list of username-password tuples) required to access launchable. Can also provide function that takes username and password and returns True if valid login.
+    auth: If provided, username and password (or list of username-password tuples) required to access the Blocks. Can also provide function that takes username and password and returns True if valid login.
     ssl_keyfile: If a path to a file is provided, will use this as the private key file to create a local server running on https.
     ssl_certfile: If a path to a file is provided, will use this as the signed certificate for https. Needs to be provided if ssl_keyfile is provided.
     ssl_keyfile_password: If a password is provided, will use this with the ssl certificate for https.
@@ -106,7 +121,7 @@ def start_server(
             s.close()
         except OSError:
             raise OSError(
-                "Port {} is in use. If a gradio.Launchable is running on the port, you can close() it or gradio.close_all().".format(
+                "Port {} is in use. If a gradio.Blocks is running on the port, you can close() it or gradio.close_all().".format(
                     server_port
                 )
             )
@@ -123,30 +138,18 @@ def start_server(
     else:
         path_to_local_server = "http://{}:{}/".format(url_host_name, port)
 
-    auth = launchable.auth
-    if auth is not None:
-        if not callable(auth):
-            app.auth = {account[0]: account[1] for account in auth}
-        else:
-            app.auth = auth
-    else:
-        app.auth = None
-    app.launchable = launchable
-    app.cwd = os.getcwd()
-    app.favicon_path = launchable.favicon_path
-    app.tokens = {}
+    app = App.create_app(blocks)
 
-    if app.launchable.enable_queue:
-        if auth is not None or app.launchable.encrypt:
+    if app.blocks.enable_queue:
+        if blocks.auth is not None or app.blocks.encrypt:
             raise ValueError("Cannot queue with encryption or authentication enabled.")
         queueing.init()
         app.queue_thread = threading.Thread(
             target=queueing.queue_thread, args=(path_to_local_server,)
         )
         app.queue_thread.start()
-    if launchable.save_to is not None:  # Used for selenium tests
-        launchable.save_to["port"] = port
-
+    if blocks.save_to is not None:  # Used for selenium tests
+        blocks.save_to["port"] = port
     config = uvicorn.Config(
         app=app,
         port=port,
