@@ -843,7 +843,9 @@ class TestAudio(unittest.TestCase):
             },
         )
         self.assertTrue(
-            audio_output.deserialize(deepcopy(media_data.BASE64_AUDIO)).endswith(".wav")
+            audio_output.deserialize(
+                deepcopy(media_data.BASE64_AUDIO)["data"]
+            ).endswith(".wav")
         )
         with tempfile.TemporaryDirectory() as tmpdirname:
             to_save = audio_output.save_flagged(
@@ -1038,6 +1040,7 @@ class TestDataframe(unittest.TestCase):
                 "elem_id": None,
                 "visible": True,
                 "interactive": None,
+                "wrap": False,
             },
         )
         dataframe_input = gr.Dataframe()
@@ -1085,6 +1088,7 @@ class TestDataframe(unittest.TestCase):
                     ["", "", ""],
                 ],
                 "interactive": None,
+                "wrap": False,
             },
         )
         with self.assertRaises(ValueError):
